summaryrefslogtreecommitdiff
path: root/src/lib/playlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/playlist.h')
-rw-r--r--src/lib/playlist.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/lib/playlist.h b/src/lib/playlist.h
index 0baf667fc..3af17bb6c 100644
--- a/src/lib/playlist.h
+++ b/src/lib/playlist.h
@@ -70,8 +70,9 @@ public:
void repeat (ContentList, int);
/** Emitted when content has been added to or removed from the playlist */
mutable boost::signals2::signal<void ()> Changed;
+ mutable boost::signals2::signal<void ()> OrderChanged;
/** Emitted when something about a piece of our content has changed;
* these emissions include when the position of the content changes.
* Third parameter is true if signals are currently being emitted frequently.
@@ -70,8 +70,9 @@ public:
void repeat (ContentList, int);
- /** Emitted when content has been added to or removed from the playlist */
+ /** Emitted when content has been added to or removed from the playlist; implies OrderChanged */
mutable boost::signals2::signal<void ()> Changed;